pub struct SurfaceComponentsModel { /* private fields */ }Expand description
Manages all components in a surface as a flat HashMap.
Implementations
Sourceimpl SurfaceComponentsModel
impl SurfaceComponentsModel
pub fn new() -> Self
Sourcepub fn get(&self, id: &str) -> Option<&ComponentModel>
pub fn get(&self, id: &str) -> Option<&ComponentModel>
Get a component by ID.
Sourcepub fn upsert(&mut self, component: ComponentModel)
pub fn upsert(&mut self, component: ComponentModel)
Add or update a component. If the component already exists with a different type, replaces it.
Sourcepub fn all(&self) -> &HashMap<String, ComponentModel>
pub fn all(&self) -> &HashMap<String, ComponentModel>
Get all components.