SurfaceModel

Struct SurfaceModel 

pub struct SurfaceModel {
    pub id: String,
    pub catalog_id: String,
    pub surface_properties: Option<Value>,
    pub send_data_model: bool,
    pub data_model: RefCell<DataModel>,
    pub components: RefCell<SurfaceComponentsModel>,
    pub pending_actions: RefCell<HashMap<String, PendingAction>>,
}
State for a single A2UI surface.

Fields

id: String

Unique surface identifier.

catalog_id: String

Catalog URI this surface uses.

surface_properties: Option<Value>

Optional surface properties (e.g. agentDisplayName).

send_data_model: bool

Whether to send the full data model with actions.

data_model: RefCell<DataModel>

The data model for this surface.

components: RefCell<SurfaceComponentsModel>

The component tree for this surface.

pending_actions: RefCell<HashMap<String, PendingAction>>

Actions that are awaiting a server response, keyed by action_id.

Implementations

Source

impl SurfaceModel

pub fn new( id: String, catalog_id: String, surface_properties: Option<Value>, send_data_model: bool, ) -> Self

Create a new surface model.

pub fn with_data_model(self, data: Value) -> Self

Initialize with a data model value.

pub fn has_root(&self) -> bool

Check if the component tree has a root component.