pub struct RefFieldSpec {
pub single_refs: &'static [&'static str],
pub list_refs: &'static [&'static str],
}Expand description
Specification of which property keys carry component references.
Fields
single_refs: &'static [&'static str]Keys whose value is a single component id string (e.g. child,
activeTab).
list_refs: &'static [&'static str]Keys whose value is a list of component ids — either a JSON array of
strings (Static), or a Template object {componentId, path}
(e.g. children).
Implementations
Sourceimpl RefFieldSpec
impl RefFieldSpec