pub struct SurfaceModel {
pub id: String,
pub catalog_id: String,
pub surface_properties: Option<Value>,
pub send_data_model: bool,
pub data_model: RefCell<DataModel>,
pub components: RefCell<SurfaceComponentsModel>,
pub pending_actions: RefCell<HashMap<String, PendingAction>>,
}Expand description
State for a single A2UI surface.
Fields
id: StringUnique surface identifier.
catalog_id: StringCatalog URI this surface uses.
surface_properties: Option<Value>Optional surface properties (e.g. agentDisplayName).
send_data_model: boolWhether to send the full data model with actions.
data_model: RefCell<DataModel>The data model for this surface.
components: RefCell<SurfaceComponentsModel>The component tree for this surface.
pending_actions: RefCell<HashMap<String, PendingAction>>Actions that are awaiting a server response, keyed by action_id.
Implementations